# bowtie

**DOI:** [10.5281/zenodo.5810334](https://doi.org/10.5281/zenodo.5810334)

## Available Versions
- **Version 1.3.1**
  - [Download](https://zenodo.org/record/5810335/files/bowtie_1.3.1.img)
  - **MD5:** `28556f0d9f81e7f7b6e9f6a63a5fd970`
  - **DOI:** [10.5281/zenodo.5810335](https://doi.org/10.5281/zenodo.5810335)
  - **Size:** 57.11 MB
  - **Binaries:** 0 available

## Binaries (9 total)

```bowtie bowtie-inspect-l bowtie-inspect-s bowtie-align-l bowtie-align-s bowtie-build bowtie-build-l bowtie-build-s bowtie-inspect```
